#myCanvas{
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column;
}
.row{
    display: flex;
    flex-direction: row;
    flex-grow: 1;
    width: 100%;
    height: 1rem;
}
    
.column{
    flex-grow: 1;
}    
.pixel{
    box-shadow: 0px 0px 0px 0px black;
    transition: all .2s linear;
}

.pixel:hover{
    box-shadow: 0px 0px 5px 1px yellow;
    z-index: 100;
}
#color-picker{
    display: flex;
    flex-direction: column;
    background-color: white;
    top:0;
    left: 0;
    justify-content: center;
    align-items: center;
}
#color-form{
    display: flex;
    flex-direction: column;
}
#example-pixel{
    color: white;
}
body{
    display:flex;
    flex-direction: row;
}

